/*
 * linux/include/asm-arm/arch-ep93xx/ep93xx-regs.h
 */

#ifndef __ASM_ARCH_EP93XX_REGS_H
#define __ASM_ARCH_EP93XX_REGS_H

/*
 * EP93xx Physical Memory Map:
 *
 * The ASDO pin is sampled at system reset to select a synchronous or
 * asynchronous boot configuration.  When ASDO is "1" (i.e. pulled-up)
 * the synchronous boot mode is selected.  When ASDO is "0" (i.e
 * pulled-down) the asynchronous boot mode is selected.
 *
 * In synchronous boot mode nSDCE3 is decoded starting at physical address
 * 0x00000000 and nCS0 is decoded starting at 0xf0000000.  For asynchronous
 * boot mode they are swapped with nCS0 decoded at 0x00000000 ann nSDCE3
 * decoded at 0xf0000000.
 *
 * There is known errata for the EP93xx dealing with External Memory
 * Configurations.  Please refer to "AN273: EP93xx Silicon Rev E Design
 * Guidelines" for more information.  This document can be found at:
 *
 *	http://www.cirrus.com/en/pubs/appNote/AN273REV4.pdf
 */

#define EP93XX_IO_BASE_VIRT		0xfef00000
#define EP93XX_IO_BASE_PHYS		0x80000000
#define EP93XX_IO_SIZE			0x00a00000

#define EP93XX_CS0_PHYS_BASE_ASYNC	0x00000000	/* ASDO Pin = 0 */
#define EP93XX_SDCE3_PHYS_BASE_SYNC	0x00000000	/* ASDO Pin = 1 */
#define EP93XX_CS1_PHYS_BASE		0x10000000
#define EP93XX_CS2_PHYS_BASE		0x20000000
#define EP93XX_CS3_PHYS_BASE		0x30000000
#define EP93XX_PCMCIA_PHYS_BASE		0x40000000
#define EP93XX_CS6_PHYS_BASE		0x60000000
#define EP93XX_CS7_PHYS_BASE		0x70000000
#define EP93XX_SDCE0_PHYS_BASE		0xc0000000
#define EP93XX_SDCE1_PHYS_BASE		0xd0000000
#define EP93XX_SDCE2_PHYS_BASE		0xe0000000
#define EP93XX_SDCE3_PHYS_BASE_ASYNC	0xf0000000	/* ASDO Pin = 0 */
#define EP93XX_CS0_PHYS_BASE_SYNC	0xf0000000	/* ASDO Pin = 1 */

/* PCMCIA */
#define EP93XX_PCMCIA_IO		EP93XX_PCMCIA_PHYS_BASE
#define EP93XX_PCMCIA_IO_SIZE		0x04000000

#define EP93XX_PCMCIA_ATTRIBUTE		(EP93XX_PCMCIA_PHYS_BASE + 0x08000000)
#define EP93XX_PCMCIA_ATTRIBUTE_SIZE	0x04000000

#define EP93XX_PCMCIA_MEMORY		(EP93XX_PCMCIA_PHYS_BASE + 0x0c000000)
#define EP93XX_PCMCIA_MEMORY_SIZE	0x04000000


/*
 * EP93xx linux memory map:
 *
 * virt		phys		size
 * fe800000			5M		per-platform mappings
 * fed00000	80800000	2M		APB
 * fef00000	80000000	1M		AHB
 */

#define EP93XX_AHB_PHYS_BASE		0x80000000
#define EP93XX_AHB_VIRT_BASE		0xfef00000
#define EP93XX_AHB_SIZE			0x00100000

#define EP93XX_APB_PHYS_BASE		0x80800000
#define EP93XX_APB_VIRT_BASE		0xfed00000
#define EP93XX_APB_SIZE			0x00200000


/* AHB peripherals */
#define EP93XX_DMA_BASE			(EP93XX_AHB_VIRT_BASE + 0x00000000)
#define EP93XX_DMA_REG(x)		(EP93XX_DMA_BASE + (x))

/* M2P/P2M Channel Register offset */
/* M2P Channel Control register bit defines */
#define EP93XX_DMA_M2P_CONTROL_OFFSET		(0x00)
#define EP93XX_DMA_M2P_CONTROL_STALLINT		(1<<0)
#define EP93XX_DMA_M2P_CONTROL_NFBINT		(1<<1)
#define EP93XX_DMA_M2P_CONTROL_CHERRORINT	(1<<3)
#define EP93XX_DMA_M2P_CONTROL_ENABLE		(1<<4)
#define EP93XX_DMA_M2P_CONTROL_ABORT		(1<<5)
#define EP93XX_DMA_M2P_CONTROL_ICE		(1<<6)
/* M2P Interrupt status register bit defines */
#define EP93XX_DMA_M2P_INTERRUPT_OFFSET		(0x04)
#define EP93XX_DMA_M2P_INTERRUPT_STALLINT	(1<<0)
#define EP93XX_DMA_M2P_INTERRUPT_NFBINT		(1<<1)
#define EP93XX_DMA_M2P_INTERRUPT_CHERRORINT	(1<<3)
/* M2P Peripheral Port Allocation register bit defines */
#define EP93XX_DMA_M2P_PPALLOC_OFFSET		(0x08)
#define EP93XX_DMA_M2P_PPALLOC_MASK		(0x0000000f)
/* M2P channel status register bit defines */
#define EP93XX_DMA_M2P_STATUS_OFFSET		(0x0C)
#define EP93XX_DMA_M2P_STATUS_STALL		(1<<0)
#define EP93XX_DMA_M2P_STATUS_NFBINT		(1<<1)
#define EP93XX_DMA_M2P_STATUS_CHERROR		(1<<3)
#define EP93XX_DMA_M2P_STATUS_CURRENT_MASK	(0x00000030)
#define EP93XX_DMA_M2P_STATUS_CURRENT_SHIFT	(4)
#define EP93XX_DMA_M2P_STATUS_CURRENT_IDLE		(0)
#define EP93XX_DMA_M2P_STATUS_CURRENT_STALL		(1)
#define EP93XX_DMA_M2P_STATUS_CURRENT_BUF_ON		(2)
#define EP93XX_DMA_M2P_STATUS_CURRENT_NEXT		(3)
#define EP93XX_DMA_M2P_STATUS_NEXTBUFFER	(1<<6)
#define EP93XX_DMA_M2P_STATUS_BYTES_MASK	(0x0000f800)
#define EP93XX_DMA_M2P_STATUS_BYTES_SHIFT	(7)
/* M2P Bytes Remaining register bit defines */
#define EP93XX_DMA_M2P_REMAIN_OFFSET		(0x14)
#define EP93XX_DMA_M2P_REMAIN_MASK		(0x0000ffff)
/* M2P Maximum byte count register 0 bit defines */
#define EP93XX_DMA_M2P_MAXCNT0_OFFSET		(0x20)
#define EP93XX_DMA_M2P_MAXCNT0_MASK		(0x0000ffff)
/* M2P Base address count 0 register bit defines */
#define EP93XX_DMA_M2P_BASE0_OFFSET		(0x24)
#define EP93XX_DMA_M2P_BASE0_MASK		(0xffffffff)
/* M2P Current address count 0 register bit defines */
#define EP93XX_DMA_M2P_CURRENT0_OFFSET		(0x28)
#define EP93XX_DMA_M2P_CURRENT0_MASK		(0xffffffff)
/* M2P Maximum byte count register 1 bit defines */
#define EP93XX_DMA_M2P_MAXCNT1_OFFSET		(0x30)
#define EP93XX_DMA_M2P_MAXCNT1_MASK		(0x0000ffff)
/* M2P Base address count 1 register bit defines */
#define EP93XX_DMA_M2P_BASE1_OFFSET		(0x34)
#define EP93XX_DMA_M2P_BASE1_MASK		(0xffffffff)
/* M2P Current address count 1 register bit defines */
#define EP93XX_DMA_M2P_CURRENT1_OFFSET		(0x38)
#define EP93XX_DMA_M2P_CURRENT1_MASK		(0xffffffff)

/* M2M Channel Register offset */
/* M2M Channel Control register bit defines */
#define EP93XX_DMA_M2M_CONTROL_OFFSET		(0x00)
#define EP93XX_DMA_M2M_CONTROL_STALLINTEN	(1<<0)
#define EP93XX_DMA_M2M_CONTROL_SCT		(1<<1)
#define EP93XX_DMA_M2M_CONTROL_DONEINTEN	(1<<2)
#define EP93XX_DMA_M2M_CONTROL_ENABLE		(1<<3)
#define EP93XX_DMA_M2M_CONTROL_START		(1<<4)
#define EP93XX_DMA_M2M_CONTROL_BWC_MASK		(0x000001e0)
#define EP93XX_DMA_M2M_CONTROL_BWC_SHIFT	(5)
#define EP93XX_DMA_M2M_CONTROL_PW_MASK		(0x00000600)
#define EP93XX_DMA_M2M_CONTROL_PW_SHIFT		(9)
#define EP93XX_DMA_M2M_CONTROL_PW_8			(0)
#define EP93XX_DMA_M2M_CONTROL_PW_16			(1)
#define EP93XX_DMA_M2M_CONTROL_PW_32			(2)
#define EP93XX_DMA_M2M_CONTROL_PW_NOUSE			(3)
#define EP93XX_DMA_M2M_CONTROL_DAH		(1<<11)
#define EP93XX_DMA_M2M_CONTROL_SAH		(1<<12)
#define EP93XX_DMA_M2M_CONTROL_TM_MASK		(0x00006000)
#define EP93XX_DMA_M2M_CONTROL_TM_SHIFT		(13)
#define EP93XX_DMA_M2M_CONTROL_TM_SOFT			(0)
#define EP93XX_DMA_M2M_CONTROL_TM_HARD_M2P		(1)
#define EP93XX_DMA_M2M_CONTROL_TM_HARD_P2M		(2)
#define EP93XX_DMA_M2M_CONTROL_TM_HARD_NOUSE		(3)
#define EP93XX_DMA_M2M_CONTROL_ETDP_MASK	(0x00018000)
#define EP93XX_DMA_M2M_CONTROL_ETDP_SHIFT	(15)
#define EP93XX_DMA_M2M_CONTROL_DACKP		(1<<17)
#define EP93XX_DMA_M2M_CONTROL_DREQP_MASK	(0x00180000)
#define EP93XX_DMA_M2M_CONTROL_DREQP_SHIFT	(19)
#define EP93XX_DMA_M2M_CONTROL_NFBINTEN		(1<<21)
#define EP93XX_DMA_M2M_CONTROL_RSS_MASK		(0x00c00000)
#define EP93XX_DMA_M2M_CONTROL_RSS_SHIFT	(22)
#define EP93XX_DMA_M2M_CONTROL_RSS_DREQ			(0)
#define EP93XX_DMA_M2M_CONTROL_RSS_SSPRX		(1)
#define EP93XX_DMA_M2M_CONTROL_RSS_SSPTX		(2)
#define EP93XX_DMA_M2M_CONTROL_RSS_IDE			(3)
#define EP93XX_DMA_M2M_CONTROL_NO_HDSK		(1<<24)
#define EP93XX_DMA_M2M_CONTROL_PWSC_MASK		(0xfe000000)
#define EP93XX_DMA_M2M_CONTROL_PWSC_SHIFT	(25)
/* M2M Interrupt status register bit defines */
#define EP93XX_DMA_M2M_INTERRUPT_OFFSET		(0x04)
#define EP93XX_DMA_M2M_INTERRUPT_STALLINT	(1<<0)
#define EP93XX_DMA_M2M_INTERRUPT_DONEINT	(1<<1)
#define EP93XX_DMA_M2M_INTERRUPT_NFBINT		(1<<2)
/* M2M channel status register bit defines */
#define EP93XX_DMA_M2M_STATUS_OFFSET		(0x0C)
#define EP93XX_DMA_M2M_STATUS_STALL		(1<<0)
#define EP93XX_DMA_M2M_STATUS_CURRENT_MASK	(0x0000003e)
#define EP93XX_DMA_M2M_STATUS_CURRENT_SHIFT	(1)
#define EP93XX_DMA_M2M_STATUS_DONE		(1<<6)
#define EP93XX_DMA_M2M_STATUS_TCS_MASK		(0x00000180)
#define EP93XX_DMA_M2M_STATUS_TCS_SHIFT		(7)
#define EP93XX_DMA_M2M_STATUS_EOTS_MASK		(0x00000600)
#define EP93XX_DMA_M2M_STATUS_EOTS_SHIFT	(9)
#define EP93XX_DMA_M2M_STATUS_NFB		(1<<11)
#define EP93XX_DMA_M2M_STATUS_NB		(1<<12)
#define EP93XX_DMA_M2M_STATUS_DREQS		(1<<13)
/* M2M Bytes count 0 register bit defines */
#define EP93XX_DMA_M2M_BCR0_OFFSET		(0x10)
#define EP93XX_DMA_M2M_BCR0_MASK		(0x0000ffff)
/* M2M Bytes count 1 register bit defines */
#define EP93XX_DMA_M2M_BCR1_OFFSET		(0x14)
#define EP93XX_DMA_M2M_BCR1_MASK		(0x0000ffff)
/* M2M base memory address 0 register bit defines */
#define EP93XX_DMA_M2M_SAR_BASE0_OFFSET		(0x18)
#define EP93XX_DMA_M2M_SAR_BASE0_MASK		(0xffffffff)
/* M2M base memory address 1 register bit defines */
#define EP93XX_DMA_M2M_SAR_BASE1_OFFSET		(0x1C)
#define EP93XX_DMA_M2M_SAR_BASE1_MASK		(0xffffffff)
/* M2M current source address 0 register bit defines */
#define EP93XX_DMA_M2M_SAR_CURRENT0_OFFSET	(0x24)
#define EP93XX_DMA_M2M_SAR_CURRENT0_MASK	(0xffffffff)
/* M2M current source address 1 register bit defines */
#define EP93XX_DMA_M2M_SAR_CURRENT1_OFFSET	(0x28)
#define EP93XX_DMA_M2M_SAR_CURRENT1_MASK	(0xffffffff)
/* M2M current base address 0 register bit defines */
#define EP93XX_DMA_M2M_DAR_BASE0_OFFSET		(0x2C)
#define EP93XX_DMA_M2M_DAR_BASE0_MASK		(0xffffffff)
/* M2M current base address 0 register bit defines */
#define EP93XX_DMA_M2M_DAR_BASE1_OFFSET		(0x30)
#define EP93XX_DMA_M2M_DAR_BASE1_MASK		(0xffffffff)
/* M2M current destination address 0 register bit defines */
#define EP93XX_DMA_M2M_DAR_CURRENT0_OFFSET	(0x34)
#define EP93XX_DMA_M2M_DAR_CURRENT0_MASK	(0xffffffff)
/* M2M current destination address 1 register bit defines */
#define EP93XX_DMA_M2M_DAR_CURRENT1_OFFSET	(0x3C)
#define EP93XX_DMA_M2M_DAR_CURRENT1_MASK	(0xffffffff)

#define EP93XX_DMA_M2P_C0_TX_BASE		(EP93XX_DMA_REG(0x0000))
#define EP93XX_DMA_M2P_C0_TX_REG(x)		(EP93XX_DMA_M2P_C0_TX_BASE + (x))
#define EP93XX_DMA_M2P_C0_TX_CONTROL		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_INTERRUPT		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_PPALLOC		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_STATUS		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_REMAIN		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_MAXCNT0		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_BASE0		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_CURRENT0		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_MAXCNT1		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_BASE1		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C0_TX_CURRENT1		EP93XX_DMA_M2P_C0_TX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_BASE		(EP93XX_DMA_REG(0x0040))
#define EP93XX_DMA_M2P_C1_RX_REG(x)		(EP93XX_DMA_M2P_C1_RX_BASE + (x))
#define EP93XX_DMA_M2P_C1_RX_CONTROL		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_INTERRUPT		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_PPALLOC		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_STATUS		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_REMAIN		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_MAXCNT0		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_BASE0		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_CURRENT0		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_MAXCNT1		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_BASE1		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C1_RX_CURRENT1		EP93XX_DMA_M2P_C1_RX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_BASE		(EP93XX_DMA_REG(0x0080))
#define EP93XX_DMA_M2P_C2_TX_REG(x)		(EP93XX_DMA_M2P_C2_TX_BASE + (x))
#define EP93XX_DMA_M2P_C2_TX_CONTROL		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_INTERRUPT		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_PPALLOC		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_STATUS		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_REMAIN		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_MAXCNT0		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_BASE0		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_CURRENT0		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_MAXCNT1		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_BASE1		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C2_TX_CURRENT1		EP93XX_DMA_M2P_C2_TX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_BASE		(EP93XX_DMA_REG(0x00C0))
#define EP93XX_DMA_M2P_C3_RX_REG(x)		(EP93XX_DMA_M2P_C3_RX_BASE + (x))
#define EP93XX_DMA_M2P_C3_RX_CONTROL		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_INTERRUPT		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_PPALLOC		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_STATUS		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_REMAIN		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_MAXCNT0		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_BASE0		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_CURRENT0		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_MAXCNT1		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_BASE1		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C3_RX_CURRENT1		EP93XX_DMA_M2P_C3_RX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2M_C0_BASE			(EP93XX_DMA_REG(0x0100))
#define EP93XX_DMA_M2M_C0_REG(x)		(EP93XX_DMA_M2M_C0_BASE + (x))
#define EP93XX_DMA_M2M_C0_CONTROL		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_CONTROL_OFFSET)
#define EP93XX_DMA_M2M_C0_INTERRUPT		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2M_C0_STATUS		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_STATUS_OFFSET)
#define EP93XX_DMA_M2M_C0_BCR0			EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_BCR0_OFFSET)
#define EP93XX_DMA_M2M_C0_BCR1			EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_BCR1_OFFSET)
#define EP93XX_DMA_M2M_C0_SAR_BASE0		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_SAR_BASE0_OFFSET)
#define EP93XX_DMA_M2M_C0_SAR_BASE1		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_SAR_BASE1_OFFSET)
#define EP93XX_DMA_M2M_C0_SAR_CURRENT0		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_SAR_CURRENT0_OFFSET)
#define EP93XX_DMA_M2M_C0_SAR_CURRENT1		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_SAR_CURRENT1_OFFSET)
#define EP93XX_DMA_M2M_C0_DAR_BASE0		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_DAR_BASE0_OFFSET)
#define EP93XX_DMA_M2M_C0_DAR_BASE1		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_DAR_BASE1_OFFSET)
#define EP93XX_DMA_M2M_C0_DAR_CURRENT0		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_DAR_CURRENT0_OFFSET)
#define EP93XX_DMA_M2M_C0_DAR_CURRENT1		EP93XX_DMA_M2M_C0_REG(EP93XX_DMA_M2M_DAR_CURRENT1_OFFSET)
#define EP93XX_DMA_M2M_C1_BASE			(EP93XX_DMA_REG(0x0140))
#define EP93XX_DMA_M2M_C1_REG(x)		(EP93XX_DMA_M2M_C1_BASE + (x))
#define EP93XX_DMA_M2M_C1_CONTROL		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_CONTROL_OFFSET)
#define EP93XX_DMA_M2M_C1_INTERRUPT		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2M_C1_STATUS		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_STATUS_OFFSET)
#define EP93XX_DMA_M2M_C1_BCR0			EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_BCR0_OFFSET)
#define EP93XX_DMA_M2M_C1_BCR1			EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_BCR1_OFFSET)
#define EP93XX_DMA_M2M_C1_SAR_BASE0		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_SAR_BASE0_OFFSET)
#define EP93XX_DMA_M2M_C1_SAR_BASE1		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_SAR_BASE1_OFFSET)
#define EP93XX_DMA_M2M_C1_SAR_CURRENT0		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_SAR_CURRENT0_OFFSET)
#define EP93XX_DMA_M2M_C1_SAR_CURRENT1		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_SAR_CURRENT1_OFFSET)
#define EP93XX_DMA_M2M_C1_DAR_BASE0		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_DAR_BASE0_OFFSET)
#define EP93XX_DMA_M2M_C1_DAR_BASE1		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_DAR_BASE1_OFFSET)
#define EP93XX_DMA_M2M_C1_DAR_CURRENT0		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_DAR_CURRENT0_OFFSET)
#define EP93XX_DMA_M2M_C1_DAR_CURRENT1		EP93XX_DMA_M2M_C1_REG(EP93XX_DMA_M2M_DAR_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_BASE		(EP93XX_DMA_REG(0x0200))
#define EP93XX_DMA_M2P_C5_RX_REG(x)		(EP93XX_DMA_M2P_C5_RX_BASE + (x))
#define EP93XX_DMA_M2P_C5_RX_CONTROL		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_INTERRUPT		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_PPALLOC		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_STATUS		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_REMAIN		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_MAXCNT0		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_BASE0		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_CURRENT0		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_MAXCNT1		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_BASE1		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C5_RX_CURRENT1		EP93XX_DMA_M2P_C5_RX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_BASE		(EP93XX_DMA_REG(0x0240))
#define EP93XX_DMA_M2P_C4_TX_REG(x)		(EP93XX_DMA_M2P_C4_TX_BASE + (x))
#define EP93XX_DMA_M2P_C4_TX_CONTROL		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_INTERRUPT		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_PPALLOC		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_STATUS		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_REMAIN		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_MAXCNT0		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_BASE0		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_CURRENT0		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_MAXCNT1		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_BASE1		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C4_TX_CURRENT1		EP93XX_DMA_M2P_C4_TX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_BASE		(EP93XX_DMA_REG(0x0280))
#define EP93XX_DMA_M2P_C7_RX_REG(x)		(EP93XX_DMA_M2P_C7_RX_BASE + (x))
#define EP93XX_DMA_M2P_C7_RX_CONTROL		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_INTERRUPT		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_PPALLOC		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_STATUS		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_REMAIN		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_MAXCNT0		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_BASE0		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_CURRENT0		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_MAXCNT1		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_BASE1		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C7_RX_CURRENT1		EP93XX_DMA_M2P_C7_RX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_BASE		(EP93XX_DMA_REG(0x02C0))
#define EP93XX_DMA_M2P_C6_TX_REG(x)		(EP93XX_DMA_M2P_C6_TX_BASE + (x))
#define EP93XX_DMA_M2P_C6_TX_CONTROL		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_INTERRUPT		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_PPALLOC		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_STATUS		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_REMAIN		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_MAXCNT0		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_BASE0		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_CURRENT0		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_MAXCNT1		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_BASE1		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C6_TX_CURRENT1		EP93XX_DMA_M2P_C6_TX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_BASE		(EP93XX_DMA_REG(0x0300))
#define EP93XX_DMA_M2P_C9_RX_REG(x)		(EP93XX_DMA_M2P_C9_RX_BASE + (x))
#define EP93XX_DMA_M2P_C9_RX_CONTROL		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_INTERRUPT		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_PPALLOC		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_STATUS		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_REMAIN		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_MAXCNT0		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_BASE0		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_CURRENT0		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_MAXCNT1		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_BASE1		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C9_RX_CURRENT1		EP93XX_DMA_M2P_C9_RX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_BASE		(EP93XX_DMA_REG(0x0340))
#define EP93XX_DMA_M2P_C8_TX_REG(x)		(EP93XX_DMA_M2P_C8_TX_BASE + (x))
#define EP93XX_DMA_M2P_C8_TX_CONTROL		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_CONTROL_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_INTERRUPT		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_INTERRUPT_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_PPALLOC		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_PPALLOC_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_STATUS		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_STATUS_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_REMAIN		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_REMAIN_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_MAXCNT0		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_MAXCNT0_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_BASE0		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_BASE0_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_CURRENT0		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_CURRENT0_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_MAXCNT1		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_MAXCMT1_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_BASE1		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_BASE1_OFFSET)
#define EP93XX_DMA_M2P_C8_TX_CURRENT1		EP93XX_DMA_M2P_C8_TX_REG(EP93XX_DMA_M2P_CURRENT1_OFFSET)
#define EP93XX_DMA_ARBITRATION		EP93XX_DMA_REG(0x0380)
#define EP93XX_DMA_INTERRUPT		EP93XX_DMA_REG(0x03C0)

#define EP93XX_ETHERNET_BASE		(EP93XX_AHB_VIRT_BASE + 0x00010000)
#define EP93XX_ETHERNET_PHYS_BASE	(EP93XX_AHB_PHYS_BASE + 0x00010000)

#define EP93XX_USB_BASE			(EP93XX_AHB_VIRT_BASE + 0x00020000)
#define EP93XX_USB_PHYS_BASE		(EP93XX_AHB_PHYS_BASE + 0x00020000)

#define EP93XX_RASTER_BASE		(EP93XX_AHB_VIRT_BASE + 0x00030000)
#define EP93XX_RASTER_PHYS_BASE		(EP93XX_AHB_PHYS_BASE + 0x00030000)
#define EP93XX_RASTER_REG(x)		(EP93XX_RASTER_BASE + (x))
#define EP93XX_RASTER_VLINESTOTAL	EP93XX_RASTER_REG(0x00)
#define EP93XX_RASTER_VSYNCSTRTSTOP	EP93XX_RASTER_REG(0x04)
#define EP93XX_RASTER_VACTIVESTRTSTOP	EP93XX_RASTER_REG(0x08)
#define EP93XX_RASTER_VCLKSTRTSTOP	EP93XX_RASTER_REG(0x0C)
#define EP93XX_RASTER_HCLKSTOTAL	EP93XX_RASTER_REG(0x10)
#define EP93XX_RASTER_HSYNCSTRTSTOP	EP93XX_RASTER_REG(0x14)
#define EP93XX_RASTER_HACTIVESTRTSTOP	EP93XX_RASTER_REG(0x18)
#define EP93XX_RASTER_HCLKSTRTSTOP	EP93XX_RASTER_REG(0x1C)
#define EP93XX_RASTER_BRIGHTNESS	EP93XX_RASTER_REG(0x20)
#define EP93XX_RASTER_VIDEOATTRIBS	EP93XX_RASTER_REG(0x24)
#define EP93XX_RASTER_VIDEOATTRIBS_EN			(1<<0)
#define EP93XX_RASTER_VIDEOATTRIBS_PCLKEN		(1<<1)
#define EP93XX_RASTER_VIDEOATTRIBS_SYNCEN		(1<<2)
#define EP93XX_RASTER_VIDEOATTRIBS_DATAEN		(1<<3)
#define EP93XX_RASTER_VIDEOATTRIBS_CSYNC		(1<<4)
#define EP93XX_RASTER_VIDEOATTRIBS_VCPOL		(1<<5)
#define EP93XX_RASTER_VIDEOATTRIBS_HSPOL		(1<<6)
#define EP93XX_RASTER_VIDEOATTRIBS_BLKPOL		(1<<7)
#define EP93XX_RASTER_VIDEOATTRIBS_INVCLK		(1<<8)
#define EP93XX_RASTER_VIDEOATTRIBS_ACEN			(1<<9)
#define EP93XX_RASTER_VIDEOATTRIBS_LCDEN		(1<<10)
#define EP93XX_RASTER_VIDEOATTRIBS_CCIREN		(1<<12)
#define EP93XX_RASTER_VIDEOATTRIBS_PIFEN		(1<<13)
#define EP93XX_RASTER_VIDEOATTRIBS_INTEN		(1<<14)
#define EP93XX_RASTER_VIDEOATTRIBS_INT			(1<<15)
#define EP93XX_RASTER_VIDEOATTRIBS_INTRLC		(1<<16)
#define EP93XX_RASTER_VIDEOATTRIBS_EQUSER		(1<<17)
#define EP93XX_RASTER_VIDEOATTRIBS_DHORZ		(1<<18)
#define EP93XX_RASTER_VIDEOATTRIBS_DVERT		(1<<19)
#define EP93XX_RASTER_VIDEOATTRIBS_BKPXD		(1<<20)
#define EP93XX_RASTER_VIDEOATTRIBS_SDSEL_MASK		(0x00600000)
#define EP93XX_RASTER_VIDSCRNPAGE	EP93XX_RASTER_REG(0x28)
#define EP93XX_RASTER_VIDSCRNHPG	EP93XX_RASTER_REG(0x2C)
#define EP93XX_RASTER_SCRNLINES		EP93XX_RASTER_REG(0x30)
#define EP93XX_RASTER_LINELENGTH	EP93XX_RASTER_REG(0x34)
#define EP93XX_RASTER_VLINESTEP		EP93XX_RASTER_REG(0x38)
#define EP93XX_RASTER_LINECARRY		EP93XX_RASTER_REG(0x3C)
#define EP93XX_RASTER_BLINKRATE		EP93XX_RASTER_REG(0x40)
#define EP93XX_RASTER_BLINKMASK		EP93XX_RASTER_REG(0x44)
#define EP93XX_RASTER_BLINKPATTRN	EP93XX_RASTER_REG(0x48)
#define EP93XX_RASTER_PATTRNMASK	EP93XX_RASTER_REG(0x4C)
#define EP93XX_RASTER_BG_OFFSET		EP93XX_RASTER_REG(0x50)
#define EP93XX_RASTER_PIXELMODE		EP93XX_RASTER_REG(0x54)
#define EP93XX_RASTER_PIXELMODE_P_MASK			0x00000007
#define EP93XX_RASTER_PIXELMODE_P_MUX_DISABLE		0x00000000            
#define EP93XX_RASTER_PIXELMODE_P_4BPP			0x00000001            
#define EP93XX_RASTER_PIXELMODE_P_8BPP			0x00000002            
#define EP93XX_RASTER_PIXELMODE_P_16BPP			0x00000004            
#define EP93XX_RASTER_PIXELMODE_P_24BPP			0x00000006            
#define EP93XX_RASTER_PIXELMODE_P_32BPP			0x00000007            
#define EP93XX_RASTER_PIXELMODE_S_MASK			0x00000038
#define EP93XX_RASTER_PIXELMODE_S_1PPC			0x00000000
#define EP93XX_RASTER_PIXELMODE_S_1PPCMAPPED		0x00000008
#define EP93XX_RASTER_PIXELMODE_S_2PPC			0x00000010
#define EP93XX_RASTER_PIXELMODE_S_4PPC			0x00000018
#define EP93XX_RASTER_PIXELMODE_S_8PPC			0x00000020
#define EP93XX_RASTER_PIXELMODE_S_223PPC		0x00000028
#define EP93XX_RASTER_PIXELMODE_S_DS223PPC		0x00000030
#define EP93XX_RASTER_PIXELMODE_S_UNDEF			0x00000038
#define EP93XX_RASTER_PIXELMODE_M_MASK			0x000003c0
#define EP93XX_RASTER_PIXELMODE_M_NOBLINK		0x00000000
#define EP93XX_RASTER_PIXELMODE_M_ANDBLINK		0x00000040
#define EP93XX_RASTER_PIXELMODE_M_ORBLINK		0x00000080
#define EP93XX_RASTER_PIXELMODE_M_XORBLINK		0x000000c0
#define EP93XX_RASTER_PIXELMODE_M_BGBLINK		0x00000100
#define EP93XX_RASTER_PIXELMODE_M_OFFSINGBLINK		0x00000140
#define EP93XX_RASTER_PIXELMODE_M_OFF888BLINK		0x00000180
#define EP93XX_RASTER_PIXELMODE_M_DIMBLINK		0x00000300
#define EP93XX_RASTER_PIXELMODE_M_BRTBLINK		0x00000340
#define EP93XX_RASTER_PIXELMODE_M_DIM888BLINK		0x00000380
#define EP93XX_RASTER_PIXELMODE_M_BRT888BLINK		0x000003c0
#define EP93XX_RASTER_PIXELMODE_C_MASK			0x00003c00
#define EP93XX_RASTER_PIXELMODE_C_LUT			0x00000000
#define EP93XX_RASTER_PIXELMODE_C_888			0x00001000
#define EP93XX_RASTER_PIXELMODE_C_565			0x00001400
#define EP93XX_RASTER_PIXELMODE_C_555			0x00001800
#define EP93XX_RASTER_PIXELMODE_C_GSLUT			0x00002000
#define EP93XX_RASTER_PIXELMODE_DSCAN			0x00004000
#define EP93XX_RASTER_PIXELMODE_TRBSW			0x00008000


#define EP93XX_RASTER_PARLLIFOUT	EP93XX_RASTER_REG(0x58)
#define EP93XX_RASTER_PARLLIFIN		EP93XX_RASTER_REG(0x5C)
#define EP93XX_RASTER_CURSOR_ADR_START	EP93XX_RASTER_REG(0x60)
#define EP93XX_RASTER_CURSOR_ADR_RESET	EP93XX_RASTER_REG(0x64)
#define EP93XX_RASTER_CURSORSIZE	EP93XX_RASTER_REG(0x68)
#define EP93XX_RASTER_CURSORCOLOR1	EP93XX_RASTER_REG(0x6C)
#define EP93XX_RASTER_CURSORCOLOR2	EP93XX_RASTER_REG(0x70)
#define EP93XX_RASTER_CURSORXYLOC	EP93XX_RASTER_REG(0x74)
#define EP93XX_RASTER_CURSORXYLOC_CEN			(1<<15)
#define EP93XX_RASTER_CURSOR_DHSCAN_LH_YLOC	EP93XX_RASTER_REG(0x78)
#define EP93XX_RASTER_RASTER_SWLOCK	EP93XX_RASTER_REG(0x7C)
#define EP93XX_RASTER_GS_LUT		EP93XX_RASTER_REG(0x80)
#define EP93XX_RASTER_RASTER_TCR	EP93XX_RASTER_REG(0x100)
#define EP93XX_RASTER_RASTER_TISRA	EP93XX_RASTER_REG(0x104)
#define EP93XX_RASTER_RASTER_TISRB	EP93XX_RASTER_REG(0x108)
#define EP93XX_RASTER_CURSOR_TISR	EP93XX_RASTER_REG(0x10C)
#define EP93XX_RASTER_RASTER_TOCRA	EP93XX_RASTER_REG(0x110)
#define EP93XX_RASTER_RASTER_TOCRB	EP93XX_RASTER_REG(0x114)
#define EP93XX_RASTER_FIFO_TOCRA	EP93XX_RASTER_REG(0x118)
#define EP93XX_RASTER_FIFO_TOCRB	EP93XX_RASTER_REG(0x11C)
#define EP93XX_RASTER_BLINK_TISR	EP93XX_RASTER_REG(0x120)
#define EP93XX_RASTER_DAC_TISRA		EP93XX_RASTER_REG(0x124)
#define EP93XX_RASTER_DAC_TISRB		EP93XX_RASTER_REG(0x128)
#define EP93XX_RASTER_SHIFT_TISR	EP93XX_RASTER_REG(0x12C)
#define EP93XX_RASTER_DACMUX_TOCRA	EP93XX_RASTER_REG(0x130)
#define EP93XX_RASTER_DACMUX_TOCRB	EP93XX_RASTER_REG(0x134)
#define EP93XX_RASTER_PELMUX_TOCR	EP93XX_RASTER_REG(0x138)
#define EP93XX_RASTER_VIDEO_TOCRA	EP93XX_RASTER_REG(0x13C)
#define EP93XX_RASTER_VIDEO_TOCRB	EP93XX_RASTER_REG(0x140)
#define EP93XX_RASTER_YCRCB_TOCR	EP93XX_RASTER_REG(0x144)
#define EP93XX_RASTER_CURSOR_TOCR	EP93XX_RASTER_REG(0x148)
#define EP93XX_RASTER_VIDEO_TOCRC	EP93XX_RASTER_REG(0x14C)
#define EP93XX_RASTER_SHIFT_TOCR	EP93XX_RASTER_REG(0x150)
#define EP93XX_RASTER_BLINK_TOCR	EP93XX_RASTER_REG(0x154)
#define EP93XX_RASTER_RASTER_TCER	EP93XX_RASTER_REG(0x180)
#define EP93XX_RASTER_SIGVAL		EP93XX_RASTER_REG(0x200)
#define EP93XX_RASTER_SIGCTL		EP93XX_RASTER_REG(0x204)
#define EP93XX_RASTER_VSIGSTRTSTOP	EP93XX_RASTER_REG(0x208)
#define EP93XX_RASTER_HSIGSTRTSTOP	EP93XX_RASTER_REG(0x20C)
#define EP93XX_RASTER_SIGCLR		EP93XX_RASTER_REG(0x210)
#define EP93XX_RASTER_ACRATE		EP93XX_RASTER_REG(0x214)
#define EP93XX_RASTER_LUTCONT		EP93XX_RASTER_REG(0x218)
#define EP93XX_RASTER_LUTCONT_SWTCH			(1<<0)
#define EP93XX_RASTER_LUTCONT_STAT			(1<<1)
#define EP93XX_RASTER_VBLANKSTRTSTOP	EP93XX_RASTER_REG(0x228)
#define EP93XX_RASTER_HBLANKSTRTSTOP	EP93XX_RASTER_REG(0x22C)
#define EP93XX_RASTER_LUT		EP93XX_RASTER_REG(0x400)
#define EP93XX_RASTER_CURSORBLINK1	EP93XX_RASTER_REG(0x21C)
#define EP93XX_RASTER_CURSORBLINK2	EP93XX_RASTER_REG(0x220)
#define EP93XX_RASTER_CURSORBLINK	EP93XX_RASTER_REG(0x224)
#define EP93XX_RASTER_CURSORBLINK_EN			(1<<8)

#define EP93XX_RASTER_EOLOFFSET		EP93XX_RASTER_REG(0x230)
#define EP93XX_RASTER_FIFOLEVEL		EP93XX_RASTER_REG(0x234)
#define EP93XX_RASTER_GS_LUT2i		EP93XX_RASTER_REG(0x280)
#define EP93XX_RASTER_GS_LUT3		EP93XX_RASTER_REG(0x300)
#define EP93XX_RASTER_COLOR_LUT		EP93XX_RASTER_REG(0x400)

#define EP93XX_GRAPHICS_ACCEL_BASE	(EP93XX_AHB_VIRT_BASE + 0x00040000)
#define EP93XX_GRAPHICS_ACCEL_REG(x)		(EP93XX_GRAPHICS_ACCEL_BASE + (x))
#define EP93XX_GRAPHICS_ACCEL_SRCPIXELSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x00)
#define EP93XX_GRAPHICS_ACCEL_DESTPIXELSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x04)
#define EP93XX_GRAPHICS_ACCEL_BLKSRCSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x08)
#define EP93XX_GRAPHICS_ACCEL_BLKDSTSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x0C)
#define EP93XX_GRAPHICS_ACCEL_BLKSRCWIDTH	EP93XX_GRAPHICS_ACCEL_REG(0x10)
#define EP93XX_GRAPHICS_ACCEL_SRCLINELENGTH	EP93XX_GRAPHICS_ACCEL_REG(0x14)
#define EP93XX_GRAPHICS_ACCEL_BLKDESTWIDTH	EP93XX_GRAPHICS_ACCEL_REG(0x18)
#define EP93XX_GRAPHICS_ACCEL_BLKDESTHEIGHT	EP93XX_GRAPHICS_ACCEL_REG(0x1C)
#define EP93XX_GRAPHICS_ACCEL_DESTLINELENGTH	EP93XX_GRAPHICS_ACCEL_REG(0x20)
#define EP93XX_GRAPHICS_ACCEL_BLOCKCTRL		EP93XX_GRAPHICS_ACCEL_REG(0x24)

#define EP93XX_GRAPHICS_ACCEL_TRANSPATTRN	EP93XX_GRAPHICS_ACCEL_REG(0x28)
#define EP93XX_GRAPHICS_ACCEL_BLOCKMASK		EP93XX_GRAPHICS_ACCEL_REG(0x2C)
#define EP93XX_GRAPHICS_ACCEL_BACKGROUND	EP93XX_GRAPHICS_ACCEL_REG(0x30)
#define EP93XX_GRAPHICS_ACCEL_LINEINC		EP93XX_GRAPHICS_ACCEL_REG(0x34)
#define EP93XX_GRAPHICS_ACCEL_LINEINIT		EP93XX_GRAPHICS_ACCEL_REG(0x38)
#define EP93XX_GRAPHICS_ACCEL_LINEPATTRN	EP93XX_GRAPHICS_ACCEL_REG(0x3C)

#define EP93XX_SDRAM_CONTROLLER_BASE	(EP93XX_AHB_VIRT_BASE + 0x00060000)

#define EP93XX_PCMCIA_CONTROLLER_BASE		(EP93XX_AHB_VIRT_BASE + 0x00080000)
#define EP93XX_PCMCIA_CONTROLLER_REG(x)		(EP93XX_PCMCIA_CONTROLLER_BASE + (x))
#define EP93XX_PCMCIA_CONTROLLER_SMCBCR0	EP93XX_PCMCIA_CONTROLLER_REG(0x00)
#define EP93XX_PCMCIA_CONTROLLER_SMCBCR1	EP93XX_PCMCIA_CONTROLLER_REG(0x04)
#define EP93XX_PCMCIA_CONTROLLER_SMCBCR2	EP93XX_PCMCIA_CONTROLLER_REG(0x08)
#define EP93XX_PCMCIA_CONTROLLER_SMCBCR3	EP93XX_PCMCIA_CONTROLLER_REG(0x0C)
#define EP93XX_PCMCIA_CONTROLLER_SMCBCR6	EP93XX_PCMCIA_CONTROLLER_REG(0x18)
#define EP93XX_PCMCIA_CONTROLLER_SMCBCR7	EP93XX_PCMCIA_CONTROLLER_REG(0x1C)
#define EP93XX_PCMCIA_CONTROLLER_PCATTRIBUTE	EP93XX_PCMCIA_CONTROLLER_REG(0x20)
#define EP93XX_PCMCIA_CONTROLLER_PCCOMMON	EP93XX_PCMCIA_CONTROLLER_REG(0x24)
#define EP93XX_PCMCIA_CONTROLLER_PCIO		EP93XX_PCMCIA_CONTROLLER_REG(0x28)
#define EP93XX_PCMCIA_CONTROLLER_SETUP_TIME_MASK		(0x000000FF)
#define EP93XX_PCMCIA_CONTROLLER_SETUP_TIME_SHIFT		(0)
#define EP93XX_PCMCIA_CONTROLLER_HOLD_TIME_MASK			(0x00000f00)
#define EP93XX_PCMCIA_CONTROLLER_HOLD_TIME_SHIFT		(8)
#define EP93XX_PCMCIA_CONTROLLER_ACCESS_TIME_MASK		(0x00ff0000)
#define EP93XX_PCMCIA_CONTROLLER_ACCESS_TIME_SHIFT		(16)
#define EP93XX_PCMCIA_CONTROLLER_MEMORY_WIDTH_8BIT		(0x00000000)
#define EP93XX_PCMCIA_CONTROLLER_MEMORY_WIDTH_16BIT		(0x80000000)
#define EP93XX_PCMCIA_CONTROLLER_PCMCIA_CTRL	EP93XX_PCMCIA_CONTROLLER_REG(0x40)
#define EP93XX_PCMCIA_CONTROLLER_PCMCIA_CTRL_PCEN		(1<<0)
#define EP93XX_PCMCIA_CONTROLLER_PCMCIA_CTRL_PCRST		(1<<2)
#define EP93XX_PCMCIA_CONTROLLER_PCMCIA_CTRL_WEN		(1<<4)

#define EP93XX_BOOT_ROM_BASE		(EP93XX_AHB_VIRT_BASE + 0x00090000)

#define EP93XX_IDE_BASE				(EP93XX_AHB_VIRT_BASE + 0x000a0000)
#define EP93XX_IDE_REG(x)			(EP93XX_IDE_BASE + (x))
#define EP93XX_IDE_CTRL				EP93XX_IDE_REG(0x00)
#define EP93XX_IDE_CTRL_CS0_OUTPUT			(1<<0)
#define EP93XX_IDE_CTRL_CS1_OUTPUT			(1<<1)
#define EP93XX_IDE_CTRL_DEV_ADDR_OUTPUT_MASK		(0x0000001C)
#define EP93XX_IDE_CTRL_DEV_ADDR_OUTPUT_SHIFT		(2)
#define EP93XX_IDE_CTRL_DIORN_OUTPUT			(1<<5)
#define EP93XX_IDE_CTRL_DIOWN_OUTPUT			(1<<6)
#define EP93XX_IDE_CTRL_DASPN_STATE			(1<<7)
#define EP93XX_IDE_CTRL_DMARQ_STATE			(1<<8)
#define EP93XX_IDE_CTRL_INTRQ_STATE			(1<<9)
#define EP93XX_IDE_CTRL_INRDY_STATE			(1<<10)
#define EP93XX_IDE_CONFIG			EP93XX_IDE_REG(0x04)
#define EP93XX_IDE_CONFIG_IDE_ENABLE			(1<<0)
#define EP93XX_IDE_CONFIG_POLL_IO			(1<<1)
#define EP93XX_IDE_CONFIG_MDMA				(1<<2)
#define EP93XX_IDE_CONFIG_UDMA				(1<<3)
#define EP93XX_IDE_CONFIG_MODE_MASK			(0x000000f0)
#define EP93XX_IDE_CONFIG_MODE_SHIFT			(4)
#define EP93XX_IDE_CONFIG_WAIT_TIME_MASK		(0x00000300)
#define EP93XX_IDE_CONFIG_WAIT_TIME_SHIFT		(8)
#define EP93XX_IDE_MDMA_OPERATION		EP93XX_IDE_REG(0x08)
#define EP93XX_IDE_UDMA_OPERATION		EP93XX_IDE_REG(0x0C)
#define EP93XX_IDE_UDMA_OPERATION_ENABLE		(1<<0)
#define EP93XX_IDE_UDMA_OPERATION_WRITE			(1<<1)
#define EP93XX_IDE_DATA_OUT			EP93XX_IDE_REG(0x10)
#define EP93XX_IDE_DATA_IN			EP93XX_IDE_REG(0x14)
#define EP93XX_IDE_MDMA_DATA_OUT		EP93XX_IDE_REG(0x18)
#define EP93XX_IDE_MDMA_DATA_IN			EP93XX_IDE_REG(0x1C)
#define EP93XX_IDE_UDMA_DATA_OUT		EP93XX_IDE_REG(0x20)
#define EP93XX_IDE_UDMA_DATA_IN			EP93XX_IDE_REG(0x24)
#define EP93XX_IDE_UDMA_STATUS			EP93XX_IDE_REG(0x28)
#define EP93XX_IDE_UDMA_DEBUG			EP93XX_IDE_REG(0x2C)
#define EP93XX_IDE_UDMA_DEBUG_WRITE_ERROR		(1<<0)
#define EP93XX_IDE_UDMA_DEBUG_WRITE_POINTER		(1<<1)
#define EP93XX_IDE_UDMA_DEBUG_WRITE_REQUEST		(1<<2)
#define EP93XX_IDE_UDMA_DEBUG_READ_ERROR		(1<<3)
#define EP93XX_IDE_UDMA_DEBUG_READ_POINTER		(1<<4)
#define EP93XX_IDE_UDMA_DEBUG_READ_REQUEST		(1<<5)
#define EP93XX_IDE_UDMA_DEBUG_MASK			(0x0000003f)
#define EP93XX_IDE_UDMA_WRITE_BUFFER_STATUS	EP93XX_IDE_REG(0x30)
#define EP93XX_IDE_UDMA_READ_BUFFER_STATUS	EP93XX_IDE_REG(0x34)
#define EP93XX_IDE_UDMA_BUFFER_STATUS_HEADPOINTER_MASK	(0x0000000f)
#define EP93XX_IDE_UDMA_BUFFER_STATUS_HEADPOINTER_SHIFT	(0)
#define EP93XX_IDE_UDMA_BUFFER_STATUS_TAILPOINTER_MASK	(0x000000f0)
#define EP93XX_IDE_UDMA_BUFFER_STATUS_TAILPOINTER_SHIFT	(4)

#define EP93XX_VIC1_BASE		(EP93XX_AHB_VIRT_BASE + 0x000b0000)

#define EP93XX_VIC2_BASE		(EP93XX_AHB_VIRT_BASE + 0x000c0000)


/* APB peripherals */
#define EP93XX_TIMER_BASE		(EP93XX_APB_VIRT_BASE + 0x00010000)
#define EP93XX_TIMER_REG(x)		(EP93XX_TIMER_BASE + (x))
#define EP93XX_TIMER1_LOAD		EP93XX_TIMER_REG(0x00)
#define EP93XX_TIMER1_VALUE		EP93XX_TIMER_REG(0x04)
#define EP93XX_TIMER1_CONTROL		EP93XX_TIMER_REG(0x08)
#define EP93XX_TIMER1_CLEAR		EP93XX_TIMER_REG(0x0c)
#define EP93XX_TIMER2_LOAD		EP93XX_TIMER_REG(0x20)
#define EP93XX_TIMER2_VALUE		EP93XX_TIMER_REG(0x24)
#define EP93XX_TIMER2_CONTROL		EP93XX_TIMER_REG(0x28)
#define EP93XX_TIMER2_CLEAR		EP93XX_TIMER_REG(0x2c)
#define EP93XX_TIMER4_VALUE_LOW		EP93XX_TIMER_REG(0x60)
#define EP93XX_TIMER4_VALUE_HIGH	EP93XX_TIMER_REG(0x64)
#define EP93XX_TIMER3_LOAD		EP93XX_TIMER_REG(0x80)
#define EP93XX_TIMER3_VALUE		EP93XX_TIMER_REG(0x84)
#define EP93XX_TIMER3_CONTROL		EP93XX_TIMER_REG(0x88)
#define EP93XX_TIMER3_CLEAR		EP93XX_TIMER_REG(0x8c)

#define EP93XX_I2S_BASE			(EP93XX_APB_VIRT_BASE + 0x00020000)

#define EP93XX_SECURITY_BASE		(EP93XX_APB_VIRT_BASE + 0x00030000)

#define EP93XX_GPIO_BASE		(EP93XX_APB_VIRT_BASE + 0x00040000)
#define EP93XX_GPIO_REG(x)		(EP93XX_GPIO_BASE + (x))
#define EP93XX_GPIO_A_DATA		EP93XX_GPIO_REG(0x00)
#define EP93XX_GPIO_B_DATA		EP93XX_GPIO_REG(0x04)
#define EP93XX_GPIO_C_DATA		EP93XX_GPIO_REG(0x08)
#define EP93XX_GPIO_D_DATA		EP93XX_GPIO_REG(0x0c)
#define EP93XX_GPIO_A_DIRECTION		EP93XX_GPIO_REG(0x10)
#define EP93XX_GPIO_B_DIRECTION		EP93XX_GPIO_REG(0x14)
#define EP93XX_GPIO_C_DIRECTION		EP93XX_GPIO_REG(0x18)
#define EP93XX_GPIO_D_DIRECTION		EP93XX_GPIO_REG(0x1c)
#define EP93XX_GPIO_E_DATA		EP93XX_GPIO_REG(0x20)
#define EP93XX_GPIO_E_DIRECTION		EP93XX_GPIO_REG(0x24)
#define EP93XX_GPIO_F_DATA		EP93XX_GPIO_REG(0x30)
#define EP93XX_GPIO_F_DIRECTION		EP93XX_GPIO_REG(0x34)
#define EP93XX_GPIO_G_DATA		EP93XX_GPIO_REG(0x38)
#define EP93XX_GPIO_G_DIRECTION		EP93XX_GPIO_REG(0x3C)
#define EP93XX_GPIO_H_DATA		EP93XX_GPIO_REG(0x40)
#define EP93XX_GPIO_H_DIRECTION		EP93XX_GPIO_REG(0x44)
#define EP93XX_GPIO_F_INT_TYPE1		EP93XX_GPIO_REG(0x4c)
#define EP93XX_GPIO_F_INT_TYPE2		EP93XX_GPIO_REG(0x50)
#define EP93XX_GPIO_F_INT_ACK		EP93XX_GPIO_REG(0x54)
#define EP93XX_GPIO_F_INT_ENABLE	EP93XX_GPIO_REG(0x58)
#define EP93XX_GPIO_F_INT_STATUS	EP93XX_GPIO_REG(0x5c)
#define EP93XX_GPIO_F_RAW_INT_STATUS	EP93XX_GPIO_REG(0x60)
#define EP93XX_GPIO_F_DEBOUNCE		EP93XX_GPIO_REG(0x64)
#define EP93XX_GPIO_A_INT_TYPE1		EP93XX_GPIO_REG(0x90)
#define EP93XX_GPIO_A_INT_TYPE2		EP93XX_GPIO_REG(0x94)
#define EP93XX_GPIO_A_INT_ACK		EP93XX_GPIO_REG(0x98)
#define EP93XX_GPIO_A_INT_ENABLE	EP93XX_GPIO_REG(0x9c)
#define EP93XX_GPIO_A_INT_STATUS	EP93XX_GPIO_REG(0xa0)
#define EP93XX_GPIO_A_RAW_INT_STATUS	EP93XX_GPIO_REG(0xa4)
#define EP93XX_GPIO_A_DEBOUNCE		EP93XX_GPIO_REG(0xa8)
#define EP93XX_GPIO_B_INT_TYPE1		EP93XX_GPIO_REG(0xac)
#define EP93XX_GPIO_B_INT_TYPE2		EP93XX_GPIO_REG(0xb0)
#define EP93XX_GPIO_B_INT_ACK		EP93XX_GPIO_REG(0xb4)
#define EP93XX_GPIO_B_INT_ENABLE	EP93XX_GPIO_REG(0xb8)
#define EP93XX_GPIO_B_INT_STATUS	EP93XX_GPIO_REG(0xbc)
#define EP93XX_GPIO_B_RAW_INT_STATUS	EP93XX_GPIO_REG(0xc0)
#define EP93XX_GPIO_B_DEBOUNCE		EP93XX_GPIO_REG(0xc4)
#define EP93XX_GPIO_G_EEPROM_DRIVE	EP93XX_GPIO_REG(0xc8)
#define EP93XX_GPIO_G_EEPROM_DRIVE_DATOD		(1<<1)
#define EP93XX_GPIO_G_EEPROM_DRIVE_CLKOD		(1<<0)

#define EP93XX_AAC_BASE			(EP93XX_APB_VIRT_BASE + 0x00080000)

#define EP93XX_SPI_BASE			(EP93XX_APB_VIRT_BASE + 0x000a0000)

#define EP93XX_IRDA_BASE		(EP93XX_APB_VIRT_BASE + 0x000b0000)

#define EP93XX_UART1_BASE		(EP93XX_APB_VIRT_BASE + 0x000c0000)
#define EP93XX_UART1_PHYS_BASE		(EP93XX_APB_PHYS_BASE + 0x000c0000)

#define EP93XX_UART2_BASE		(EP93XX_APB_VIRT_BASE + 0x000d0000)
#define EP93XX_UART2_PHYS_BASE		(EP93XX_APB_PHYS_BASE + 0x000d0000)

#define EP93XX_UART3_BASE		(EP93XX_APB_VIRT_BASE + 0x000e0000)
#define EP93XX_UART3_PHYS_BASE		(EP93XX_APB_PHYS_BASE + 0x000e0000)

#define EP93XX_KEY_MATRIX_BASE		(EP93XX_APB_VIRT_BASE + 0x000f0000)

#define EP93XX_ADC_BASE			(EP93XX_APB_VIRT_BASE + 0x00100000)
#define EP93XX_TOUCHSCREEN_BASE		(EP93XX_APB_VIRT_BASE + 0x00100000)

#define EP93XX_PWM_BASE			(EP93XX_APB_VIRT_BASE + 0x00110000)

#define EP93XX_RTC_BASE			(EP93XX_APB_VIRT_BASE + 0x00120000)

#define EP93XX_SYSCON_BASE		(EP93XX_APB_VIRT_BASE + 0x00130000)
#define EP93XX_SYSCON_REG(x)		(EP93XX_SYSCON_BASE + (x))
#define EP93XX_SYSCON_POWER_STATE	EP93XX_SYSCON_REG(0x00)
#define EP93XX_SYSCON_CLOCK_CONTROL	EP93XX_SYSCON_REG(0x04)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C1		(1<<16)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C0		(1<<17)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C3		(1<<18)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C2		(1<<19)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C5		(1<<20)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C4		(1<<21)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C7		(1<<22)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C6		(1<<23)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C9		(1<<24)
#define EP93XX_SYSCON_CLOCK_DMA_M2P_C8		(1<<25)
#define EP93XX_SYSCON_CLOCK_DMA_M2M_C0		(1<<26)
#define EP93XX_SYSCON_CLOCK_DMA_M2M_C1		(1<<27)
#define EP93XX_SYSCON_CLOCK_USH_EN		(1<<28)
#define EP93XX_SYSCON_CLOCK_UARTBAUD		(1<<29)
#define EP93XX_SYSCON_CLOCK_FIR_EN		(1<<31)
#define EP93XX_SYSCON_HALT		EP93XX_SYSCON_REG(0x08)
#define EP93XX_SYSCON_STANDBY		EP93XX_SYSCON_REG(0x0c)
#define EP93XX_SYSCON_CLOCK_SET1	EP93XX_SYSCON_REG(0x20)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2IPD_SHIFT	(0)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2IPD_MASK	(0x0000001f)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2FBD2_SHIFT	(5)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2FBD2_MASK	(0x000007e0)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X1FBD1_SHIFT	(11)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X1FBD1_MASK	(0x0000f800)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_PS_SHIFT		(16)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_PS_MASK		(0x00030000)
#define EP93XX_SYSCON_CLOCK_SET1_PCLKDIV_SHIFT		(18)
#define EP93XX_SYSCON_CLOCK_SET1_PCLKDIV_MASK		(0x000c0000)
#define EP93XX_SYSCON_CLOCK_SET1_HCLKDIV_SHIFT		(20)
#define EP93XX_SYSCON_CLOCK_SET1_HCLKDIV_MASK		(0x00700000)
#define EP93XX_SYSCON_CLOCK_SET1_nBYP1			(0x00800000)
#define EP93XX_SYSCON_CLOCK_SET1_SMCROM			(0x01000000)
#define EP93XX_SYSCON_CLOCK_SET1_FCLKDIV_SHIFT		(25)
#define EP93XX_SYSCON_CLOCK_SET1_FCLKDIV_MASK		(0x0e000000)
#define EP93XX_SYSCON_CLOCK_SET2	EP93XX_SYSCON_REG(0x24)
#define EP93XX_SYSCON_BMAR		EP93XX_SYSCON_REG(0x54)
#define EP93XX_SYSCON_DEVICE_CONFIG	EP93XX_SYSCON_REG(0x80)
#define EP93XX_SYSCON_DEVICE_CONFIG_U3EN		(1<<24)
#define EP93XX_SYSCON_DEVICE_CONFIG_CRUNCH_ENABLE	(1<<23)
#define EP93XX_SYSCON_DEVICE_CONFIG_U2EN		(1<<20)
#define EP93XX_SYSCON_DEVICE_CONFIG_EXVC		(1<<19)
#define EP93XX_SYSCON_DEVICE_CONFIG_U1EN		(1<<18)
#define EP93XX_SYSCON_DEVICE_CONFIG_HONIDE		(1<<11)
#define EP93XX_SYSCON_DEVICE_CONFIG_GONIDE		(1<<10)
#define EP93XX_SYSCON_DEVICE_CONFIG_EONIDE		(1<<8)
#define EP93XX_SYSCON_DEVICE_CONFIG_RASONP3		(1<<4)


#define EP93XX_SYSCON_SWLOCK		EP93XX_SYSCON_REG(0xc0)
#define EP93XX_SYSCON_VIDEO_CLOCK	EP93XX_SYSCON_REG(0x84)
#define EP93XX_SYSCON_VIDEO_CLOCK_VDIV_MASK         0x0000007f              
#define EP93XX_SYSCON_VIDEO_CLOCK_VDIV_SHIFT        0
#define EP93XX_SYSCON_VIDEO_CLOCK_PDIV_MASK         0x00000300
#define EP93XX_SYSCON_VIDEO_CLOCK_PDIV_SHIFT        8
#define EP93XX_SYSCON_VIDEO_CLOCK_PSEL              0x00002000
#define EP93XX_SYSCON_VIDEO_CLOCK_ESEL              0x00004000
#define EP93XX_SYSCON_VIDEO_CLOCK_VENA              0x00008000

#define EP93XX_SYSCON_CHIP_ID		EP93XX_SYSCON_REG(0x94)
#define EP93XX_SYSCON_CHIP_ID_ID_SHIFT	        (0)
#define EP93XX_SYSCON_CHIP_ID_ID_MASK		(0x0000ffff)              
#define EP93XX_SYSCON_CHIP_ID_REVISION_SHIFT	(28)
#define EP93XX_SYSCON_CHIP_ID_REVISION_MASK	(0xf0000000)              
#define EP93XX_SYSCON_CHIP_ID_REVISION_D0	(0x3)
#define EP93XX_SYSCON_CHIP_ID_REVISION_D1	(0x4)
#define EP93XX_SYSCON_CHIP_ID_REVISION_E0	(0x5)
#define EP93XX_SYSCON_CHIP_ID_REVISION_E1	(0x6)
#define EP93XX_SYSCON_CHIP_ID_REVISION_E2	(0x7)

#define EP93XX_WATCHDOG_BASE		(EP93XX_APB_VIRT_BASE + 0x00140000)


#endif
